Index: configure
===================================================================
--- configure	(revision 27001)
+++ configure	(working copy)
@@ -1795,7 +1795,7 @@
 	  result "ok"
 	  ftglincdir=`pkg-config --cflags-only-I ftgl | sed 's/-I//g'`
 	  ftgllibs=`pkg-config --libs-only-l ftgl`
-	  ftgllibdir=`pkg-config --libs-only-L ftgl | sed 's/-L//g'`
+	  ftgllibdir=`pkg-config --libs-only-L ftgl`
 	  enable_builtin_ftgl=no
       else
 	  enable_builtin_ftgl=yes
@@ -2843,21 +2843,21 @@
     # for a system library, then see if we have various headers needed.
     if test "x$enable_builtin_afterimage" = "xyes" ; then
        check_header "jpeglib.h" "" $ASIMAGE $ASIMAGE/include \
-          /usr/local/include /usr/include /opt/include
+          $finkdir/include /usr/local/include /usr/include /opt/include
        asjpegincdir=$found_dir
        check_header "png.h" "" $ASIMAGE $ASIMAGE/include $ASPNG/include \
-          /usr/local/include /usr/include /usr/local/include/libpng \
+          $finkdir/include /usr/local/include /usr/include /usr/local/include/libpng \
           /opt/include
        aspngincdir=$found_dir
        if test ! "x$enable_astiff" = "xno" ; then
            check_header "tiffio.h" "" $ASIMAGE $ASIMAGE/include \
-               /usr/local/include /usr/include /opt/include
+               $finkdir/include /usr/local/include /usr/include /opt/include
            astiffincdir=$found_dir
        else
            astiffincdir="--with-tiff=no"
        fi
        check_header "gif_lib.h" "" $ASIMAGE $ASIMAGE/include \
-          /usr/local/include /usr/include /opt/include
+          $finkdir/include /usr/local/include /usr/include /opt/include
        asgifincdir=$found_dir
 
        asextralib=""
@@ -2875,7 +2875,7 @@
        fi
        for k in $aslibs ; do
            check_library $k "$enable_shared" "" \
-             $ASIMAGE $ASIMAGE/lib $ASPNG/lib /usr/local/lib /usr/lib /opt/lib
+             $ASIMAGE $ASIMAGE/lib $ASPNG/lib $finkdir/lib /usr/local/lib /usr/lib /opt/lib
            if test "x$k" = "xlibz" ; then
                found_libz=$found_lib
                found_dirz=$found_dir
Index: tutorials/pyroot/rootmarks.py
===================================================================
--- tutorials/pyroot/rootmarks.py	(revision 27001)
+++ tutorials/pyroot/rootmarks.py	(working copy)
@@ -2,7 +2,7 @@
 #  The ROOTMARK number printed is by reference to a Pentium IV 2.4 Ghz
 #  (with 512 MBytes memory and 120 GBytes IDE disk)
 #  taken by definition as 600 ROOTMARKS in batch mode in executing
-#     python benchmarks.py
+#     python2.6 benchmarks.py
 #
 
 import os
Index: tutorials/pyroot/demo.py
===================================================================
--- tutorials/pyroot/demo.py	(revision 27001)
+++ tutorials/pyroot/demo.py	(working copy)
@@ -1,7 +1,7 @@
 import os, sys
 import ROOT
 
-# To run, do an "execfile( '<path-to>/demo.py' )" or "python <path-to>/demo.py"
+# To run, do an "execfile( '<path-to>/demo.py' )" or "python2.6 <path-to>/demo.py"
 
 # enable running from another directory than the one where demo.py resides
 workdir = os.path.dirname( sys.argv[0] )
Index: core/base/src/TSystem.cxx
===================================================================
--- core/base/src/TSystem.cxx	(revision 27001)
+++ core/base/src/TSystem.cxx	(working copy)
@@ -30,6 +30,7 @@
 #include <errno.h>
 #include <algorithm>
 
+#include "RConfigure.h"
 #include "Riostream.h"
 #include "TSystem.h"
 #include "TApplication.h"
Index: bindings/pyroot/Module.mk
===================================================================
--- bindings/pyroot/Module.mk	(revision 27001)
+++ bindings/pyroot/Module.mk	(working copy)
@@ -3,6 +3,11 @@
 #
 # Authors: Pere Mato, Wim Lavrijsen, 22/4/2004
 
+# Hack to link against fink's python
+PYTHONLIBDIR  := 
+PYTHONLIB     := 
+PYROOTLIBDEPM := @PREFIX@/lib/python2.6/config/libpython2.6.dylib
+
 MODNAME      := pyroot
 MODDIR       := bindings/$(MODNAME)
 MODDIRS      := $(MODDIR)/src
@@ -76,8 +81,8 @@
 include/%.h:    $(PYROOTDIRI)/%.h
 		cp $< $@
 
-%.pyc: %.py;    python -c 'import py_compile; py_compile.compile( "$<" )'
-%.pyo: %.py;    python -O -c 'import py_compile; py_compile.compile( "$<" )'
+%.pyc: %.py;    python2.6 -c 'import py_compile; py_compile.compile( "$<" )'
+%.pyo: %.py;    python2.6 -O -c 'import py_compile; py_compile.compile( "$<" )'
 
 $(PYROOTLIB):   $(PYROOTO) $(PYROOTDO) $(ROOTPY) $(ROOTPYC) $(ROOTPYO) \
                 $(ROOTLIBSDEP)
Index: cint/ROOT/cintdlls.mk
===================================================================
--- cint/ROOT/cintdlls.mk	(revision 27001)
+++ cint/ROOT/cintdlls.mk	(working copy)
@@ -158,6 +158,11 @@
   $(CINTDLLS): MAKELIB := $(subst -x,,$(MAKELIB))
 endif
 
+# Filter out version information
+ifneq ($(subst build/unix/makelib.sh,,$(MAKELIB)),$(MAKELIB))
+  $(CINTDLLS): MAKELIB := $(filter-out $(MKLIBOPTIONS),$(MAKELIB))
+endif
+
 $(ALLCINTDLLS): $(ORDER_) $(MAINLIBS)
 
 $(CINTDLLDIRSTL)/%.dll: $(CINTDLLDIRDLLSTL)/G__cpp_%.o 
Index: cint/reflex/python/genreflex/Makefile.am
===================================================================
--- cint/reflex/python/genreflex/Makefile.am	(revision 27001)
+++ cint/reflex/python/genreflex/Makefile.am	(working copy)
@@ -23,11 +23,11 @@
 
 if PLATFORM_IS_WINDOWS 
 SCRIPT_TXT_L1 = "@echo off"
-SCRIPT_TXT_L2 = "python $(pkgpyexecdir)/genreflex.py %*"
+SCRIPT_TXT_L2 = "python2.6 $(pkgpyexecdir)/genreflex.py %*"
 SCRIPT_NAME   = "$(bindir)/genreflex.bat"
 else 
 SCRIPT_TXT_L1 = "\#!/bin/csh -f"
-SCRIPT_TXT_L2 = "python $(pkgpyexecdir)/genreflex.py $$""*"
+SCRIPT_TXT_L2 = "python2.6 $(pkgpyexecdir)/genreflex.py $$""*"
 SCRIPT_NAME   = "$(bindir)/genreflex"
 endif
 
Index: cint/reflex/Module.mk
===================================================================
--- cint/reflex/Module.mk	(revision 27001)
+++ cint/reflex/Module.mk	(working copy)
@@ -119,7 +119,7 @@
 		cp $< $@
 
 $(RFLX_GRFLXDD)/%.pyc: $(RFLX_GRFLXDD)/%.py
-		@python -c 'import py_compile; py_compile.compile( "$<" )'
+		@python2.6 -c 'import py_compile; py_compile.compile( "$<" )'
 
 $(RFLX_GENMAPO) : $(RFLX_GENMAPS)
 	$(CXX) $(OPT) $(CXXFLAGS) -Iinclude -I$(REFLEXDIRS)/genmap -c $< $(CXXOUT)$@
Index: cint/cintex/Module.mk
===================================================================
--- cint/cintex/Module.mk	(revision 27001)
+++ cint/cintex/Module.mk	(working copy)
@@ -66,7 +66,7 @@
 endif
 endif
 
-GENREFLEX_CMD2 = python ../../../../lib/python/genreflex/genreflex.py
+GENREFLEX_CMD2 = python2.6 ../../../../lib/python/genreflex/genreflex.py
 
 CINTEXTESTD     = $(CINTEXDIR)/test
 CINTEXTESTDICTD = $(CINTEXTESTD)/dict
@@ -86,8 +86,8 @@
 		fi)
 		cp $< $@
 
-%.pyc: %.py;    python -c 'import py_compile; py_compile.compile( "$<" )'
-%.pyo: %.py;    python -O -c 'import py_compile; py_compile.compile( "$<" )'
+%.pyc: %.py;    python2.6 -c 'import py_compile; py_compile.compile( "$<" )'
+%.pyo: %.py;    python2.6 -O -c 'import py_compile; py_compile.compile( "$<" )'
 
 $(CINTEXLIB):   $(CINTEXO) $(CINTEXPY) $(CINTEXPYC) $(CINTEXPYO) \
                 $(ORDER_) $(subst $(CINTEXLIB),,$(MAINLIBS)) $(CINTEXLIBDEP)
Index: graf3d/gl/src/TGLText.cxx
===================================================================
--- graf3d/gl/src/TGLText.cxx	(revision 27001)
+++ graf3d/gl/src/TGLText.cxx	(working copy)
@@ -19,11 +19,6 @@
 #include "TEnv.h"
 #include "TGLIncludes.h"
 
-// Direct inclussion of FTGL headers is deprecated in ftgl-2.1.3 while
-// ftgl-2.1.2 shipped with root requires manual inclusion.
-#ifndef BUILTIN_FTGL
-# include <FTGL/ftgl.h>
-#else
 # include "FTFont.h"
 # include "FTGLExtrdFont.h"
 # include "FTGLOutlineFont.h"
@@ -31,7 +26,6 @@
 # include "FTGLTextureFont.h"
 # include "FTGLPixmapFont.h"
 # include "FTGLBitmapFont.h"
-#endif
 
 #define FTGL_BITMAP  0
 #define FTGL_PIXMAP  1
Index: graf3d/gl/src/TGLFontManager.cxx
===================================================================
--- graf3d/gl/src/TGLFontManager.cxx	(revision 27001)
+++ graf3d/gl/src/TGLFontManager.cxx	(working copy)
@@ -18,11 +18,6 @@
 #include "TGLUtil.h"
 #include "TGLIncludes.h"
 
-// Direct inclussion of FTGL headers is deprecated in ftgl-2.1.3 while
-// ftgl-2.1.2 shipped with root requires manual inclusion.
-#ifndef BUILTIN_FTGL
-# include <FTGL/ftgl.h>
-#else
 # include "FTFont.h"
 # include "FTGLExtrdFont.h"
 # include "FTGLOutlineFont.h"
@@ -30,7 +25,6 @@
 # include "FTGLTextureFont.h"
 # include "FTGLPixmapFont.h"
 # include "FTGLBitmapFont.h"
-#endif
 
 //______________________________________________________________________________
 // TGLFont
Index: Makefile
===================================================================
--- Makefile	(revision 27001)
+++ Makefile	(working copy)
@@ -174,7 +174,7 @@
 MODULES      += graf2d/qt gui/qtroot
 endif
 ifeq ($(BUILDQTGSI),yes)
-MODULES      += gui/qtgsi
+MODULES      += gui/qtgsi gui/qtgui
 endif
 ifeq ($(BUILDGENVECTOR),yes)
 MODULES      += math/genvector
@@ -261,7 +261,7 @@
                 rootx net/rootd io/dcache io/chirp hist/hbook graf2d/asimage \
                 net/ldap net/krb5auth net/rpdutils net/globusauth \
                 bindings/pyroot bindings/ruby io/gfal misc/minicern \
-                graf2d/qt gui/qtroot gui/qtgsi net/xrootd net/netx net/alien \
+                graf2d/qt gui/qtroot gui/qtgsi gui/qtgui net/xrootd net/netx net/alien \
                 proof/proofd proof/proofx proof/clarens proof/peac \
                 sql/oracle io/xmlparser math/mathmore cint/reflex cint/cintex \
                 cint/cint7 roofit/roofitcore roofit/roofit roofit/roostats \
Index: net/xrootd/src/xrootd/src/XrdPosix/GNUmakefile
===================================================================
--- net/xrootd/src/xrootd/src/XrdPosix/GNUmakefile	(revision 27001)
+++ net/xrootd/src/xrootd/src/XrdPosix/GNUmakefile	(working copy)
@@ -88,7 +88,7 @@
 $(LIBRARY): $(OBJECTP) $(OBJECTS) $(OBJECTT) $(LIBDEP)
 	@echo Creating shared library $(LIBRARY) 
 	$(ECHO)$(CC) $(CFLAGS) $(OBJECTS) $(OBJECTU) $(LDSO) $(MORELIBS) $(LIBS) -o $(LIBRARY)
-ifneq ($(subst $(MACOSX_MINOR),,1234),1234)
+ifneq ($(subst $(MACOSX_MINOR),,12345),12345)
 	$(ECHO)if [ "x$(TYPE)" = "xDarwin" ]; then \
 	   $(CC) $(CFLAGS) $(OBJECTS) $(TYPELDDY) $(MORELIBS) $(LIBS) -o $(LIBDIR)/libXrdPosix.$(TYPEDYLIB); \
 	fi
Index: net/xrootd/src/xrootd/src/XrdClient/GNUmakefile
===================================================================
--- net/xrootd/src/xrootd/src/XrdClient/GNUmakefile	(revision 27001)
+++ net/xrootd/src/xrootd/src/XrdClient/GNUmakefile	(working copy)
@@ -155,7 +155,7 @@
 	@echo Creating shared library $(LIBSHARED) 
 	$(ECHO)rm -f $(LIBSHARED)
 	$(ECHO)$(CC) $(CFLAGS) $(OBJECTS) $(LDSO) $(LIBLIBS) $(LIBS) -o $(LIBSHARED)
-ifneq ($(subst $(MACOSX_MINOR),,1234),1234)
+ifneq ($(subst $(MACOSX_MINOR),,12345),12345)
 	$(ECHO)if [ "x$(TYPE)" = "xDarwin" ]; then \
 	          $(CC) $(CFLAGS) $(OBJECTS) $(TYPELDDY) $(LIBLIBS) $(LIBS) -o $(LIBDIR)/libXrdClient.$(TYPEDYLIB); \
 	fi
Index: net/xrootd/src/xrootd/config/GNUmake.rules.macos
===================================================================
--- net/xrootd/src/xrootd/config/GNUmake.rules.macos	(revision 27001)
+++ net/xrootd/src/xrootd/config/GNUmake.rules.macos	(working copy)
@@ -20,11 +20,11 @@
 TYPELINK   = -undefined dynamic_lookup -multiply_defined suppress 
 TYPEOPT    = $(TYPEMISC) $(TYPELINK) -O2
 TYPEDBG    = $(TYPEMISC) $(TYPELINK) -g
-ifeq ($(subst $(MACOSX_MINOR),,1234),1234)
+ifeq ($(subst $(MACOSX_MINOR),,123),123)
 TYPELDSO   = $(TYPELINK) -dynamiclib -single_module
 TYPELDDY   = $(TYPELINK) -dynamiclib -single_module
-TYPESHLIB  = so
-TYPEDYLIB  = so
+TYPESHLIB  = dylib
+TYPEDYLIB  = dylib
 else
 TYPELDSO   = $(TYPELINK) -bundle
 TYPELDDY   = $(TYPELINK) -dynamiclib -single_module
Index: net/xrootd/Module.mk
===================================================================
--- net/xrootd/Module.mk	(revision 27001)
+++ net/xrootd/Module.mk	(working copy)
@@ -29,7 +29,7 @@
 endif
 endif
 ifeq ($(PLATFORM),macosx)
-XRDSOEXT    = so
+XRDSOEXT    = dylib
 else
 XRDSOEXT    = $(SOEXT)
 endif
Index: build/unix/makelib.sh
===================================================================
--- build/unix/makelib.sh	(revision 27001)
+++ build/unix/makelib.sh	(working copy)
@@ -34,7 +34,7 @@
 if [ $PLATFORM = "macosx" ]; then
    macosx_minor=`sw_vers | sed -n 's/ProductVersion://p' | cut -d . -f 2`
    if [ $macosx_minor -ge 5 ] && [ $LD != "icpc" ]; then
-      soext="so"
+      soext="dylib"
    else
       soext="dylib"
    fi
@@ -210,7 +210,7 @@
 	ln -fs $SONAME.$MAJOR        $LIB
     elif [ -f $LIBVERS ]; then
 	# Versioned library has format foo.3.05.so
-	source_file=`echo $SONAME | sed "s/.*\./&${MINOR}./"`
+	source_file=`/usr/bin/basename $SONAME | sed "s/.*\./&${MINOR}./"`
 	LIBNOMAJORMINOR=`echo $LIB|sed 's,\.'$MAJOR'\.'$MINOR',,'`
 	if [ $LIB != $LIBNOMAJORMINOR ]; then
 	    LIBNOMINOR=`echo $LIB|sed 's,\.'$MINOR',,'`
Index: config/genreflex-rootcint.in
===================================================================
--- config/genreflex-rootcint.in	(revision 27001)
+++ config/genreflex-rootcint.in	(working copy)
@@ -1,2 +1,2 @@
 #!/bin/sh
-python @libdir@/python/genreflex/genreflex-rootcint.py "$@"
+python2.6 @libdir@/python/genreflex/genreflex-rootcint.py "$@"
Index: config/rootrc.in
===================================================================
--- config/rootrc.in	(revision 27001)
+++ config/rootrc.in	(working copy)
@@ -521,3 +521,7 @@
 # This overrides the default specified above for a generic application.
 # Color 5 is yellow.
 Rint.Canvas.HighLightColor:      5
+
+# Plugins used for qt
++Plugin.TGuiFactory: qtgui     TQtGUIFactory     QtRootGui "TQtGUIFactory()"
++Plugin.TGuiFactory: qt        TQtRootGuiFactory QtRoot    "TQtRootGuiFactory()"
Index: config/Makefile.macosx64
===================================================================
--- config/Makefile.macosx64	(revision 27001)
+++ config/Makefile.macosx64	(working copy)
@@ -74,7 +74,7 @@
 endif
 endif
 ifeq ($(subst $(MACOSX_MINOR),,1234),1234)
-SOEXT         = so
+SOEXT         = dylib
 else
 SOEXT         = dylib
 endif
@@ -97,7 +97,6 @@
 endif
 
 ifneq ($(findstring g77, $(F77)),)
-F77           = g77
 F77FLAGS      = -m64
 F77LIBS       = -L$(FINK_DIR)/lib -lg2c
 endif
Index: config/genreflex.in
===================================================================
--- config/genreflex.in	(revision 27001)
+++ config/genreflex.in	(working copy)
@@ -1,2 +1,2 @@
 #!/bin/sh
-python @libdir@/python/genreflex/genreflex.py "$@"
+python2.6 @libdir@/python/genreflex/genreflex.py "$@"
Index: config/Makefile.macosx
===================================================================
--- config/Makefile.macosx	(revision 27001)
+++ config/Makefile.macosx	(working copy)
@@ -89,7 +89,7 @@
 endif
 endif
 ifeq ($(subst $(MACOSX_MINOR),,1234),1234)
-SOEXT         = so
+SOEXT         = dylib
 else
 SOEXT         = dylib
 endif
@@ -102,19 +102,11 @@
 
 # Fortran:
 ifneq ($(findstring gfortran, $(F77)),)
-ifeq ($(F77),)
-# only needed to get default compiler in ./configure
-F77           = gfortran
-endif
 F77LIBS      := $(shell $(F77) -print-file-name=libgfortran.dylib)
 F77LIBS      += $(shell $(F77) -print-file-name=libgfortranbegin.a)
 endif
 
 ifneq ($(findstring g77, $(F77)),)
-ifeq ($(F77),)
-# only needed to get default compiler in ./configure
-F77           = g77
-endif
 F77LIBS       = -L$(FINK_DIR)/lib -lg2c
 endif
 
Index: config/Makefile.depend
===================================================================
--- config/Makefile.depend	(revision 27001)
+++ config/Makefile.depend	(working copy)
@@ -83,6 +83,7 @@
 KRB5AUTHLIBDEPM        = $(RAUTHLIB) $(NETLIB)
 SRVAUTHLIBDEPM         = $(NETLIB)
 QTGSILIBDEPM           = $(GUILIB) $(GPADLIB)
+QTGUILIBDEPM           = $(QTGSILIBDEPM)
 FITPANELLIBDEPM        = $(GUILIB) $(GPADLIB) $(HISTLIB) $(GRAFLIB) $(TREELIB) \
 			 $(MATHCORELIB)
 RFIOLIBDEPM            = $(IOLIB)
@@ -177,6 +178,7 @@
 KRB5AUTHLIBDEP         = $(KRB5AUTHLIBDEPM)
 SRVAUTHLIBDEP          = $(SRVAUTHLIBDEPM)
 QTGSILIBDEP            = $(QTGSILIBDEPM)
+QTGUILIBDEP            = $(QTGUILIBDEPM)
 FITPANELLIBDEP         = $(FITPANELLIBDEPM)
 RFIOLIBDEP             = $(RFIOLIBDEPM)
 DCACHELIBDEP           = $(DCACHELIBDEPM)
@@ -347,101 +349,116 @@
 MATRIXLIBEXTRA          = -Llib -lMathCore
 HISTLIBEXTRA            = -Llib -lMatrix -lMathCore
 GRAFLIBEXTRA            = -Llib -lHist -lMatrix -lRIO -lMathCore
-GPADLIBEXTRA            = -Llib -lGraf -lHist
-G3DLIBEXTRA             = -Llib -lGraf -lHist -lGpad -lMathCore
-GEDLIBEXTRA             = -Llib -lHist -lGpad -lGraf -lGui -lTree -lTreePlayer
-POSTSCRIPTLIBEXTRA      = -Llib -lGraf
-GUILIBEXTRA             = -Llib -lGpad -lGraf -lRIO -lMathCore
-HISTPAINTERLIBEXTRA     = -Llib -lGraf -lHist -lMatrix -lGpad -lMathCore
-SPECTRUMPAINTERLIBEXTRA = -Llib -lGraf -lHist
-HTMLLIBEXTRA            = -Llib -lGraf -lThread
-MINUITLIBEXTRA          = -Llib -lGraf -lHist -lMatrix -lMathCore
-MINUIT2LIBEXTRA         = -Llib -lGraf -lHist -lMatrix -lMathCore
-FUMILILIBEXTRA          = -Llib -lGraf -lHist -lMathCore
-TREELIBEXTRA            = -Llib -lNet -lRIO -lThread
+GPADLIBEXTRA            = -Llib -lGraf -lHist -lMatrix -lRIO -lMathCore
+G3DLIBEXTRA             = -Llib -lGraf -lHist -lGpad -lMathCore -lMatrix -lRIO
+GEDLIBEXTRA             = -Llib -lHist -lGpad -lGraf -lGui -lTree -lTreePlayer \
+                          -lMatrix -lMathCore -lRIO -lNet -lThread -lGraf3d
+POSTSCRIPTLIBEXTRA      = -Llib -lGraf -lHist -lMatrix -lRIO -lMathCore
+GUILIBEXTRA             = -Llib -lGpad -lGraf -lRIO -lMathCore -lHist -lMatrix
+HISTPAINTERLIBEXTRA     = -Llib -lGraf -lHist -lMatrix -lGpad -lMathCore -lRIO
+SPECTRUMPAINTERLIBEXTRA = -Llib -lGraf -lHist -lMatrix -lRIO -lMathCore
+HTMLLIBEXTRA            = -Llib -lGraf -lThread -lHist -lMatrix -lRIO -lMathCore
+MINUITLIBEXTRA          = -Llib -lGraf -lHist -lMatrix -lMathCore -lRIO
+MINUIT2LIBEXTRA         = -Llib -lGraf -lHist -lMatrix -lMathCore -lRIO
+FUMILILIBEXTRA          = -Llib -lGraf -lHist -lMathCore -lMatrix -lRIO
+TREELIBEXTRA            = -Llib -lNet -lRIO -lThread -lMathCore
 TREEPLAYERLIBEXTRA      = -Llib -lTree -lGraf3d -lGraf -lHist -lGpad -lRIO \
-                          -lMathCore
+                          -lMathCore -lNet -lThread -lMatrix
 TREEVIEWERLIBEXTRA      = -Llib -lTree -lGpad -lGraf -lHist -lGui -lTreePlayer \
-                          -lGed -lRIO -lMathCore
+                          -lGed -lRIO -lMathCore -lNet -lThread -lMatrix -lGraf3d
 PROOFLIBEXTRA           = -Llib -lNet -lTree -lThread -lRIO -lMathCore
 PROOFPLAYERLIBEXTRA     = -Llib -lProof -lHist -lTree -lRIO -lNet -lThread \
-                          -lMathCore
+                          -lMathCore -lMatrix
 PROOFDRAWLIBEXTRA       = -Llib -lTreePlayer -lGraf3d -lGraf -lGpad \
-                          -lProofPlayer -lHist -lTree -lProof
-PROOFXLIBEXTRA          = -Llib -lNet -lProof -lThread
-SESSIONVIEWERLIBEXTRA   = -Llib -lProof -lGui -lHist -lGpad -lGraf -lTree \
-                          -lMathCore
+                          -lProofPlayer -lHist -lTree -lProof -lRIO \
+                          -lMathCore -lNet -lThread -lMatrix
+PROOFXLIBEXTRA          = -Llib -lNet -lProof -lThread -lRIO -lMathCore -lTree
+SESSIONVIEWERLIBEXTRA   = -Llib -lProof -lGui -lGpad -lGraf -lTree \
+                          -lMathCore -lNet -lThread -lRIO -lHist -lMatrix
 PEACLIBEXTRA            = -Llib -lProof -lClarens
 PEACGUILIBEXTRA         = -Llib -lGui
-X3DLIBEXTRA             = -Llib -lGraf3d -lGui
-EGLIBEXTRA              = -Llib -lGraf3d -lGraf -lGpad -lMathCore
-VMCLIBEXTRA             = -Llib -lEG -lGeom -lMathCore
+X3DLIBEXTRA             = -Llib -lGraf3d -lGui -lGraf -lHist -lGpad -lMathCore -lMatrix -lRIO
+EGLIBEXTRA              = -Llib -lGraf3d -lGraf -lGpad -lMathCore -lHist -lMatrix -lRIO
+VMCLIBEXTRA             = -Llib -lEG -lGeom -lMathCore -lGraf3d -lGraf -lGpad -lHist \
+                          -lMatrix -lRIO
 PHYSICSLIBEXTRA         = -Llib -lMatrix -lMathCore
-PYTHIA6LIBEXTRA         = -Llib -lEG -lGraf -lVMC -lPhysics $(FPYTHIA6LIBDIR) \
-                          $(FPYTHIA6LIB)
-PYTHIA8LIBEXTRA         = -Llib -lEG -lGraf -lVMC -lPhysics $(FPYTHIA8LIBDIR) \
-                          $(FPYTHIA8LIB)
-X11TTFLIBEXTRA          = -Llib -lGX11 -lGraf
+PYTHIA6LIBEXTRA         = -Llib -lEG -lGraf -lVMC -lPhysics \
+                          -lGraf3d -lGpad -lMathCore -lHist -lMatrix -lRIO \
+                          $(FPYTHIA6LIBDIR) $(FPYTHIA6LIB)
+PYTHIA8LIBEXTRA         = -Llib -lEG -lGraf -lVMC -lPhysics -lGeom \
+                          -lGraf3d -lGpad -lMathCore -lHist -lMatrix -lRIO \
+                          $(FPYTHIA8LIBDIR) $(FPYTHIA8LIB)
+X11TTFLIBEXTRA          = -Llib -lGX11 -lGraf -lHist -lMatrix -lRIO -lMathCore
 TABLELIBEXTRA           = -Llib -lTree -lGpad -lGraf3d -lGraf -lHist -lRIO \
-                          -lMathCore
+                          -lMathCore -lNet -lThread -lMatrix
 GLLIBEXTRA              = -Llib -lGpad -lGraf3d -lGui -lGraf -lHist -lGed \
-                          -lMathCore
+                          -lMathCore -lMatrix -lRIO -lTree -lTreePlayer -lNet -lThread
 HBOOKLIBEXTRA           = -Llib -lHist -lMatrix -lTree -lGraf -lTreePlayer \
-                          -lRIO -lminicern
+                          -lRIO -lminicern -lMathCore -lNet -lThread -lGraf3d -lGpad
 GEOMLIBEXTRA            = -Llib -lRIO -lMathCore
-GEOMPAINTERLIBEXTRA     = -Llib -lGeom -lTree -lGraf3d -lHist -lGpad -lRIO \
-                          -lMathCore
-GEOMBUILDERLIBEXTRA     = -Llib -lGeom -lGraf3d -lGpad -lGraf -lGui -lGed
-ASIMAGELIBEXTRA         = -Llib -lGraf -lMathCore
-ASIMAGEGUILIBEXTRA      = -Llib -lGraf -lHist -lGui -lASImage -lRIO
+GEOMPAINTERLIBEXTRA     = -Llib -lGeom -lTree -lGraf3d -lHist -lGpad -lRIO -lMathCore \
+                          -lNet -lThread -lGraf -lMatrix
+GEOMBUILDERLIBEXTRA     = -Llib -lGeom -lGraf3d -lGpad -lGraf -lGui -lGed -lRIO \
+                          -lMathCore -lHist -lMatrix -lTree -lTreePlayer -lNet -lThread
+ASIMAGELIBEXTRA         = -Llib -lGraf -lMathCore -lHist -lMatrix -lRIO
+ASIMAGEGUILIBEXTRA      = -Llib -lGraf -lHist -lGui -lASImage -lRIO -lMatrix -lMathCore \
+                          -lGpad
 ASIMAGEGSLIBEXTRA       = -Llib -lGraf -lASImage
 MLPLIBEXTRA             = -Llib -lHist -lMatrix -lTree -lGraf -lGpad \
-                          -lTreePlayer -lMathCore
-SPECTRUMLIBEXTRA        = -Llib -lHist -lMatrix
+                          -lTreePlayer -lMathCore -lNet -lRIO -lThread -lGraf3d
+SPECTRUMLIBEXTRA        = -Llib -lHist -lMatrix -lMathCore
 TMVALIBEXTRA            = -Llib -lRIO -lHist -lMatrix -lTree -lGraf -lGpad \
-                          -lTreePlayer -lMLP -lMinuit -lMathCore
+                          -lTreePlayer -lMLP -lMinuit -lMathCore -lNet -lThread -lGraf3d
 SPLOTLIBEXTRA           = -Llib -lMatrix -lHist -lTree -lTreePlayer -lGraf3d \
-                          -lGraf -lMathCore
-QTROOTLIBEXTRA          = -Llib -lGui -lGQt
-GQTLIBEXTRA             = -Llib -lGui -lGpad -lGraf -lRint
-QUADPLIBEXTRA           = -Llib -lMatrix
-RUBYLIBEXTRA            = -Llib -lHist -lMathCore
-GUIBLDLIBEXTRA          = -Llib -lGui -lGraf -lMathCore
-GUIHTMLLIBEXTRA         = -Llib -lGui -lGraf -lNet
+                          -lGraf -lMathCore -lNet -lRIO -lThread -lGpad
+QTROOTLIBEXTRA          = -Llib -lGui -lGQt -lGpad -lGraf -lRIO -lMathCore -lHist \
+                          -lMatrix -lRint 
+GQTLIBEXTRA             = -Llib -lGui -lGpad -lGraf -lRint -lRIO -lMathCore -lHist \
+                          -lMatrix \
+                          -F@PREFIX@/lib/qt4-mac/lib -Wl,-framework,QtGui \
+                          -Wl,-framework,Qt3Support
+QUADPLIBEXTRA           = -Llib -lMatrix -lMathCore
+RUBYLIBEXTRA            = -Llib -lHist -lMathCore -lMatrix
+GUIBLDLIBEXTRA          = -Llib -lGui -lGraf -lMathCore -lGpad -lRIO -lHist -lMatrix
+GUIHTMLLIBEXTRA         = -Llib -lGui -lGraf -lNet -lGpad -lRIO -lMathCore -lHist -lMatrix
 XMLLIBEXTRA             = -Llib -lRIO
-FOAMLIBEXTRA            = -Llib -lHist
+FOAMLIBEXTRA            = -Llib -lHist -lMatrix -lMathCore
 ALIENLIBEXTRA           = -Llib -lXMLIO -lNetx -lTree -lProofPlayer -lNet -lRIO
 ROOFITCORELIBEXTRA      = -Llib -lHist -lGraf -lMatrix -lTree -lMinuit -lRIO \
-                          -lMathCore
-ROOFITLIBEXTRA          = -Llib -lRooFitCore -lTree -lRIO -lMatrix -lMathCore
+                          -lMathCore -lNet -lThread
+ROOFITLIBEXTRA          = -Llib -lRooFitCore -lTree -lRIO -lMatrix \
+                          -lHist -lMathCore -lGraf -lMinuit -lNet -lThread
 ROOSTATSLIBEXTRA        = -Llib -lRooFit -lRooFitCore -lTree -lRIO -lMatrix \
                           -lHist -lMathCore -lGraf -lGpad
 CINT7LIBEXTRA           = -Llib -lReflex
 CINTEXLIBEXTRA          = -Llib -lReflex
 REFLEXDICTLIBEXTRA      = -Llib -lReflex
-RAUTHLIBEXTRA           = -Llib -lNet -lRIO
-KRB5AUTHLIBEXTRA        = -Llib -lRootAuth -lNet
-SRVAUTHLIBEXTRA         = -Llib -lNet
-QTGSILIBEXTRA           = -Llib -lGui -lGpad
-FITPANELLIBEXTRA        = -Llib -lGui -lGpad -lHist -lGraf -lTree -lMathCore
+RAUTHLIBEXTRA           = -Llib -lNet -lRIO -lMathCore
+KRB5AUTHLIBEXTRA        = -Llib -lRootAuth -lNet -lRIO -lMathCore
+SRVAUTHLIBEXTRA         = -Llib -lNet -lRIO -lMathCore
+QTGSILIBEXTRA           = -Llib -lGui -lGpad -lGraf -lRIO -lMathCore -lHist -lMatrix
+QTGUILIBEXTRA           = -Llib -lQtGSI -lGui -lGpad -lGraf -lRIO -lMathCore -lHist -lMatrix
+FITPANELLIBEXTRA        = -Llib -lGui -lGpad -lHist -lGraf -lTree -lMathCore -lRIO \
+                          -lMatrix -lNet -lThread
 RFIOLIBEXTRA            = -Llib -lRIO
 DCACHELIBEXTRA          = -Llib -lRIO
 CHIRPLIBEXTRA           = -Llib -lRIO
 GFALLIBEXTRA            = -Llib -lRIO
-SQLLIBEXTRA             = -Llib -lNet -lRIO
-ODBCLIBEXTRA            = -Llib -lNet -lRIO
-NETXLIBEXTRA            = -Llib -lNet -lRIO -lThread
+SQLLIBEXTRA             = -Llib -lNet -lRIO -lMathCore
+ODBCLIBEXTRA            = -Llib -lNet -lRIO -lMathCore
+NETXLIBEXTRA            = -Llib -lNet -lRIO -lThread -lMathCore
 ORACLELIBEXTRA          = -Llib -lNet -lRIO
 CASTORLIBEXTRA          = -Llib -lNet -lRIO
 PGSQLLIBEXTRA           = -Llib -lNet -lRIO
-MYSQLLIBEXTRA           = -Llib -lNet -lRIO
-GDMLLIBEXTRA            = -Llib -lGeom -lXMLIO -lHist -lRIO
-UNURANLIBEXTRA          = -Llib -lHist -lMathCore
+MYSQLLIBEXTRA           = -Llib -lNet -lRIO -lMathCore
+GDMLLIBEXTRA            = -Llib -lGeom -lXMLIO -lHist -lRIO -lMathCore -lMatrix
+UNURANLIBEXTRA          = -Llib -lHist -lMathCore -lMatrix
 MONALISALIBEXTRA        = -Llib -lNet -lRIO
 THREADLIBEXTRA          = -Llib -lRIO
 EVELIBEXTRA             = -Llib -lGeom -lGeomPainter -lGraf3d -lGui -lGpad \
                           -lGraf -lHist -lPhysics -lGed -lEG -lTree \
-                          -lTreePlayer -lRGL -lRIO -lRint -lMathCore
+                          -lTreePlayer -lRGL -lRIO -lRint -lMathCore \
+                          -lNet -lThread -lMatrix
 MEMSTATLIBEXTRA         = -Llib -lTree
 MEMSTATGUILIBEXTRA      = -Llib -lMemStat -lTree -lGui
 RECLIBEXTRA             = -Llib -lGui -lRIO -lTree -lThread
Index: main/src/h2root.cxx
===================================================================
--- main/src/h2root.cxx	(revision 27001)
+++ main/src/h2root.cxx	(working copy)
@@ -35,22 +35,29 @@
 #include "TMath.h"
 
 //  Define the names of the Fortran common blocks for the different OSs
-
+// Note that with gcc3.4 or above the size of PAWC_SIZE must be the same 
+// as in the Fortran definition in hbook.f and zebra
+// Also, the arrays must be declared extern like on Windows
 #ifndef WIN32
-#define PAWC_SIZE 5000000
+#define PAWC_SIZE 4000000
 #  define pawc pawc_
 #  define quest quest_
 #  define hcbits hcbits_
 #  define hcbook hcbook_
 #  define rzcl rzcl_
-int pawc[PAWC_SIZE];
-int quest[100];
-int hcbits[37];
-int hcbook[51];
-int rzcl[11];
+//int pawc[PAWC_SIZE];
+//int quest[100];
+//int hcbits[37];
+//int hcbook[51];
+//int rzcl[11];
+extern "C" int pawc[PAWC_SIZE];
+extern "C" int quest[100];
+extern "C" int hcbits[37];
+extern "C" int hcbook[51];
+extern "C" int rzcl[11];
 #else
 // on windows /pawc/ must have the same length as in libPacklib.a !!
-#define PAWC_SIZE 2000000
+#define PAWC_SIZE 4000000
 #  define pawc   PAWC
 #  define quest  QUEST
 #  define hcbits HCBITS
Index: main/src/setpawc.c
===================================================================
--- main/src/setpawc.c	(revision 27001)
+++ main/src/setpawc.c	(working copy)
@@ -7,5 +7,5 @@
 //*--  for the /PAWC/ common block for H2Root C++ utility.
 //*--  This common is defined as "external" in the H2Root and
 //*--  its size is ignored by linker.
-int PAWC[2000000];
+int PAWC[4000000];
 void setpawc(){}
Index: misc/minicern/src/hbook.f
===================================================================
--- misc/minicern/src/hbook.f	(revision 27001)
+++ misc/minicern/src/hbook.f	(working copy)
@@ -26,7 +26,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -163,7 +163,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -380,7 +380,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -613,7 +613,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -665,7 +665,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -708,7 +708,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -803,7 +803,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -912,7 +912,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -990,7 +990,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -1078,7 +1078,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -1185,7 +1185,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -1548,7 +1548,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -1597,7 +1597,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -1693,7 +1693,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -1812,7 +1812,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -1864,7 +1864,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -1912,7 +1912,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -1955,7 +1955,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -2093,7 +2093,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -2217,7 +2217,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -2329,7 +2329,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -2389,7 +2389,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -2488,7 +2488,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -2732,7 +2732,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -2783,7 +2783,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -2854,7 +2854,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -2940,7 +2940,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -3077,7 +3077,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -3232,7 +3232,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -3280,7 +3280,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -3328,7 +3328,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -3377,7 +3377,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -3497,7 +3497,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -3563,7 +3563,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -3620,7 +3620,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -3678,7 +3678,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -3773,7 +3773,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -3846,7 +3846,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
@@ -3963,7 +3963,7 @@
       INTEGER     NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,        LMAIN
       REAL                                       FENC   ,      HCV
       COMMON/PAWC/NWPAW,IXPAWC,IHDIV,IXHIGZ,IXKU,FENC(5),LMAIN,
-     +HCV(2000000-11)
+     +HCV(4000000-11)
       INTEGER   IQ        ,LQ
       REAL            Q
       DIMENSION IQ(2),Q(2),LQ(8000)
Index: misc/minicern/src/zebra.f
===================================================================
--- misc/minicern/src/zebra.f	(revision 27001)
+++ misc/minicern/src/zebra.f	(working copy)
@@ -203,7 +203,7 @@
 
       SUBROUTINE MZPAW (NWORDS,CHOPT)
       COMMON /PAWC/  NWPAW,IXPAWC,IHBOOK,IXHIGZ,IXKU,IFENCE(5)
-     +,              LMAIN, IPAW(9989)
+     +,              LMAIN, IPAW(4000000-11)
       CHARACTER    *(*) CHOPT
       CALL UOPTC (CHOPT,'M',IPAW)
       IF (IPAW(1).NE.0)   CALL MZEBRA(-1)

Index: tmva/test/TMVAnalysis.py
===================================================================
--- tmva/test/TMVAnalysis.py	(revision 27001)
+++ tmva/test/TMVAnalysis.py	(working copy)
@@ -15,13 +15,13 @@
 # The methods to be used can be switched on and off via the prompt command, for  #
 # example:                                                                       #
 #                                                                                #
-#    python TMVAnalysis.py --methods Fisher,Likelihood                           #
+#    python2.6 TMVAnalysis.py --methods Fisher,Likelihood                        #
 #                                                                                #
 # The output file "TMVA.root" can be analysed with the use of dedicated          #
 # macros (simply say: root -l <../macros/macro.C>), which can be conveniently    #
 # invoked through a GUI that will appear at the end of the run of this macro.    #
 #                                                                                #
 # for help type "python TMVAnalysis.py --help"                                   #
 # ------------------------------------------------------------------------------ #
 
 # --------------------------------------------
@@ -42,7 +42,7 @@
 # Print usage help
 def usage():
     print " "
-    print "Usage: python %s [options]" % sys.argv[0]
+    print "Usage: python2.6 %s [options]" % sys.argv[0]
     print "  -m | --methods    : gives methods to be run (default: all methods)"
     print "  -i | --inputfile  : name of input ROOT file (default: '%s')" % DEFAULT_INFNAME
     print "  -o | --outputfile : name of output ROOT file containing results (default: '%s')" % DEFAULT_OUTFNAME
@@ -15,13 +15,13 @@
 # invoked through a GUI that will appear at the end of the run of this macro.    #
 #                                                                                #
-# for help type "python TMVAnalysis.py --help"                                   #
+# for help type "python2.6 TMVAnalysis.py --help"                                #
 # ------------------------------------------------------------------------------ #
 
Index: tmva/test/TMVApplication.py
===================================================================
--- tmva/test/TMVApplication.py	(revision 27001)
+++ tmva/test/TMVApplication.py	(working copy)
@@ -8,7 +8,7 @@
 # This macro provides a simple example on how to use the trained classifiers     #
 # within an analysis module                                                      #
 #                                                                                #
 # for help type "python TMVApplication.py --help"                                #
 # ------------------------------------------------------------------------------ #
 
 # --------------------------------------------
@@ -31,7 +31,7 @@
 # Print usage help
 def usage():
     print " "
-    print "Usage: python %s [options]" % sys.argv[0]
+    print "Usage: python2.6 %s [options]" % sys.argv[0]
     print "  -m | --methods    : gives methods to be run (default: all methods)"
     print "  -i | --inputfile  : name of input ROOT file (default: '%s')" % DEFAULT_INFNAME
     print "  -o | --outputfile : name of output ROOT file containing results (default: '%s')" % DEFAULT_OUTFNAME
@@ -8,7 +8,7 @@
 # within an analysis module                                                      #
 #                                                                                #
-# for help type "python TMVApplication.py --help"                                #
+# for help type "python2.6 TMVApplication.py --help"                             #
 # ------------------------------------------------------------------------------ #
 